%global pypi_name pyahocorasick

Name:           python-%{pypi_name}
Version:        2.0.0
Release:        %autorelease
Summary:        Python module (C extension and plain Python) implementing Aho-Corasick algorithm

License:        BSD-3-Clause
URL:            https://github.com/WojciechMula/pyahocorasick
Source:         %URL/archive/%{version}/%{pypi_name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  python3-devel
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(sphinx)

%global common_description %{expand:
pyahocorasick is a fast and memory efficient library for exact or approximate
multi-pattern string search meaning that you can find multiple key strings
occurrences at once in some input text. The strings "index" can be built ahead
of time and saved (as a pickle) to disk to reload and reuse later. The library
provides an ahocorasick Python module that you can use as a plain dict-like Trie
or convert a Trie to an automaton for efficient Aho-Corasick search.

pyahocorasick is implemented in C and tested on Python 3.6 and up. It works on
64 bits Linux, macOS and Windows.}

%description %{common_description}

%package -n python3-%{pypi_name}
Summary:        %{summary}

%description -n python3-%{pypi_name} %{common_description}

%package -n python-%{pypi_name}-doc
Summary:        Documentation for python-%{pypi_name}
BuildArch:      noarch

%description -n python-%{pypi_name}-doc
%{common_description}

This package is providing the documentation for %{pypi_name}.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires -t

%build
%pyproject_wheel

# generate html docs
sphinx-build-3 -b html docs/ html
# remove the sphinx-build-3 leftovers
rm -rf html/.{doctrees,buildinfo}

%install
%pyproject_install

%check
%pytest

%files -n python3-%{pypi_name}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python3_sitearch}/ahocorasick.*.so
%{python3_sitearch}/%{pypi_name}-%{version}.dist-info

%files -n python-%{pypi_name}-doc
%doc html
%license LICENSE

%changelog
%autochangelog
